powered by
Open the official hex sticker for the car package in your browser
carHexsticker()
Used for its side effect of openning the hex sticker for the car package in your browser.
John Fox [email protected]
if (FALSE) # intended for interactive use carHexsticker()
Run the code above in your browser using DataLab