carWeb: Access to the R Companion to Applied Regression Website

carWebR Documentation

Access to the R Companion to Applied Regression Website

Description

This function will access the website for An R Companion to Applied Regression.

Usage

carWeb(...)

Arguments

...

optional arguments if present are passed to utils::browseURL

Value

Displays the web page for An R Companion to Applied Regression, Third Edition, Sage


car documentation built on Feb. 3, 2026, 5:07 p.m.